#!/usr/bin/env python
# coding: utf-8

# Copyright (c) nicolvisser.
# Distributed under the terms of the Modified BSD License.

import pytest

from ..spectrogramplayer import SpectrogramPlayer


def test_example_creation_blank():
    w = SpectrogramPlayer()
    #TODO: Add tests here
